@@ -1,35 +1,31 @@
 package Net::DNS::RR::NSEC;
 
-#
-# $Id: NSEC.pm 1690 2018-07-03 09:02:10Z willem $
-#
-our $VERSION = (qw$LastChangedRevision: 1690 $)[1];
-
-
 use strict;
 use warnings;
+our $VERSION = (qw$Id: NSEC.pm 2002 2025-01-07 09:57:46Z willem $)[2];
+
 use base qw(Net::DNS::RR);
 
+
 =head1 NAME
 
 Net::DNS::RR::NSEC - DNS NSEC resource record
 
 =cut
 
-
 use integer;
 
 use Net::DNS::DomainName;
-use Net::DNS::Parameters;
+use Net::DNS::Parameters qw(:type);
 
 
 sub _decode_rdata {			## decode rdata from wire-format octet string
-	my $self = shift;
-	my ( $data, $offset ) = @_;
+	my ( $self, $data, $offset ) = @_;
 
 	my $limit = $offset + $self->{rdlength};
-	( $self->{nxtdname}, $offset ) = decode Net::DNS::DomainName(@_);
+	( $self->{nxtdname}, $offset ) = Net::DNS::DomainName->decode( $data, $offset );
 	$self->{typebm} = substr $$data, $offset, $limit - $offset;
+	return;
 }
 
 
@@ -37,7 +33,7 @@ sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
 	my $nxtdname = $self->{nxtdname};
-	join '', $nxtdname->encode(), $self->{typebm};
+	return join '', $nxtdname->encode(), $self->{typebm};
 }
 
 
@@ -45,40 +41,51 @@ sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
 	my $nxtdname = $self->{nxtdname};
-	my @rdata = ( $nxtdname->string(), $self->typelist );
+	return ( $nxtdname->string(), $self->typelist );
 }
 
 
 sub _parse_rdata {			## populate RR from rdata in argument list
+	my ( $self, @argument ) = @_;
+
+	$self->nxtdname( shift @argument );
+	$self->typelist(@argument);
+	return;
+}
+
+
+sub _defaults {				## specify RR attribute default values
 	my $self = shift;
 
-	$self->nxtdname(shift);
-	$self->typelist(@_);
+	$self->_parse_rdata('.');
+	return;
 }
 
 
 sub nxtdname {
-	my $self = shift;
-
-	$self->{nxtdname} = new Net::DNS::DomainName(shift) if scalar @_;
-	$self->{nxtdname}->name if $self->{nxtdname};
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{nxtdname} = Net::DNS::DomainName->new($_) }
+	return $self->{nxtdname} ? $self->{nxtdname}->name : undef;
 }
 
 
 sub typelist {
-	my $self = shift;
+	my ( $self, @argument ) = @_;
 
-	$self->{typebm} = &_type2bm if scalar @_;
+	if ( scalar(@argument) || !defined(wantarray) ) {
+		$self->{typebm} = &_type2bm(@argument);
+		return;
+	}
 
-	my @type = defined wantarray ? &_bm2type( $self->{typebm} ) : ();
+	my @type = &_bm2type( $self->{typebm} );
 	return wantarray ? (@type) : "@type";
 }
 
 
 sub typemap {
-	my $self = shift;
+	my ( $self, $type ) = @_;
 
-	my $number = typebyname(shift);
+	my $number = typebyname($type);
 	my $window = $number >> 8;
 	my $bitnum = $number & 255;
 
@@ -96,9 +103,16 @@ sub typemap {
 }
 
 
+sub match {
+	my ( $self, $qname ) = @_;
+	my $name = Net::DNS::DomainName->new($qname)->canonical;
+	return $name eq $self->{owner}->canonical;
+}
+
+
 sub covers {
-	my $self = shift;
-	my $name = join chr(0), reverse Net::DNS::DomainName->new(shift)->_wire;
+	my ( $self, $qname ) = @_;
+	my $name = join chr(0), reverse Net::DNS::DomainName->new($qname)->_wire;
 	my $this = join chr(0), reverse $self->{owner}->_wire;
 	my $next = join chr(0), reverse $self->{nxtdname}->_wire;
 	foreach ( $name, $this, $next ) {tr /\101-\132/\141-\172/}
@@ -108,11 +122,39 @@ sub covers {
 }
 
 
+sub encloser {
+	my ( $self, $qname ) = @_;
+	my @label = Net::DNS::Domain->new($qname)->label;
+
+	my @owner = $self->{owner}->label;
+	my $depth = scalar(@owner);
+	my $next;
+	while ( scalar(@label) > $depth ) {
+		$next = shift @label;
+	}
+
+	return unless defined $next;
+
+	my $nextcloser = join( '.', $next, @label );
+	return if lc($nextcloser) ne lc( join '.', $next, @owner );
+
+	$self->{nextcloser} = $nextcloser;
+	$self->{wildcard}   = join( '.', '*', @label );
+	return $self->owner;
+}
+
+
+sub nextcloser { return shift->{nextcloser}; }
+
+sub wildcard { return shift->{wildcard}; }
+
+
 ########################################
 
 sub _type2bm {
+	my @typelist = @_;
 	my @typearray;
-	foreach my $typename ( map split(), @_ ) {
+	foreach my $typename ( map { split() } @typelist ) {
 		my $number = typebyname($typename);
 		my $window = $number >> 8;
 		my $bitnum = $number & 255;
@@ -125,7 +167,7 @@ sub _type2bm {
 	my $window = 0;
 	foreach (@typearray) {
 		if ( my $pane = $typearray[$window] ) {
-			my @content = map $_ || 0, @$pane;
+			my @content = map { $_ || 0 } @$pane;
 			$bitmap .= pack 'CC C*', $window, scalar(@content), @content;
 		}
 		$window++;
@@ -136,11 +178,12 @@ sub _type2bm {
 
 
 sub _bm2type {
-	my @typelist;
-	my $bitmap = shift || return @typelist;
+	my @empty;
+	my $bitmap = shift || return @empty;
 
 	my $index = 0;
 	my $limit = length $bitmap;
+	my @typelist;
 
 	while ( $index < $limit ) {
 		my ( $block, $size ) = unpack "\@$index C2", $bitmap;
@@ -163,11 +206,19 @@ sub _bm2type {
 
 
 sub typebm {				## historical
-	my $self = shift;					# uncoverable pod
-	$self->{typebm} = shift if scalar @_;
+	my ( $self, @typebm ) = @_;				# uncoverable pod
+	for (@typebm) { $self->{typebm} = $_ }
+	$self->_deprecate('prefer $rr->typelist() or $rr->typemap()');
 	return $self->{typebm};
 }
 
+sub covered {				## historical
+	my ( $self, @argument ) = @_;				# uncoverable pod
+	return $self->covers(@argument);
+}
+
+########################################
+
 
 1;
 __END__
@@ -175,8 +226,8 @@ __END__
 
 =head1 SYNOPSIS
 
-    use Net::DNS;
-    $rr = new Net::DNS::RR( 'name NSEC nxtdname typelist' );
+	use Net::DNS;
+	$rr = Net::DNS::RR->new( 'name NSEC nxtdname typelist' );
 
 =head1 DESCRIPTION
 
@@ -194,8 +245,8 @@ other unpredictable behaviour.
 
 =head2 nxtdname
 
-    $nxtdname = $rr->nxtdname;
-    $rr->nxtdname( $nxtdname );
+	$nxtdname = $rr->nxtdname;
+	$rr->nxtdname( $nxtdname );
 
 The Next Domain field contains the next owner name (in the
 canonical ordering of the zone) that has authoritative data
@@ -203,34 +254,58 @@ or contains a delegation point NS RRset.
 
 =head2 typelist
 
-    @typelist = $rr->typelist;
-    $typelist = $rr->typelist;
+	@typelist = $rr->typelist;
+	$typelist = $rr->typelist;
 
-The Type List identifies the RRset types that exist at the NSEC RR
+typelist() identifies the RRset types that exist at the NSEC RR
 owner name.  When called in scalar context, the list is interpolated
 into a string.
 
 =head2 typemap
 
-    $exists = $rr->typemap($rrtype);
+	$exists = $rr->typemap($rrtype);
 
 typemap() returns a Boolean true value if the specified RRtype occurs
-in the typelist of the NSEC record.
+in the type bitmap of the NSEC record.
+
+=head2 match
+
+	$matched = $rr->match( 'example.foo' );
+
+match() returns a Boolean true value if the canonical form of the name
+argument matches the canonical owner name of the NSEC RR.
+
 
 =head2 covers
 
-    $covered = $rr->covers( 'example.foo' );
+	$covered = $rr->covers( 'example.foo' );
 
 covers() returns a Boolean true value if the canonical form of the name,
 or one of its ancestors, falls between the owner name and the nxtdname
 field of the NSEC record.
 
+=head2 encloser, nextcloser, wildcard
+
+	$encloser = $rr->encloser( 'example.foo' );
+	print "encloser: $encloser\n" if $encloser;
+
+encloser() returns the name of a provable encloser of the query name
+argument obtained from the NSEC RR.
+
+nextcloser() returns the next closer name, which is one label longer
+than the closest encloser.
+This is only valid after encloser() has returned a valid domain name.
+
+wildcard() returns the unexpanded wildcard name from which the next
+closer name was possibly synthesised.
+This is only valid after encloser() has returned a valid domain name.
+
 
 =head1 COPYRIGHT
 
 Copyright (c)2001-2005 RIPE NCC.  Author Olaf M. Kolkman
 
-Portions Copyright (c)2018 Dick Franks
+Portions Copyright (c)2018-2019 Dick Franks
 
 All rights reserved.
 
@@ -241,7 +316,7 @@ Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
 
 Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, provided
-that the above copyright notice appear in all copies and that both that
+that the original copyright notices appear in all copies and that both
 copyright notice and this permission notice appear in supporting
 documentation, and that the name of the author not be used in advertising
 or publicity pertaining to distribution of the software without specific
@@ -258,6 +333,8 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC4034, RFC3755
+L<perl> L<Net::DNS> L<Net::DNS::RR>
+L<RFC4034(4)|https://iana.org/go/rfc4034#section-4>
+L<RFC9077|https://iana.org/go/rfc9077>
 
 =cut
